==> zookeeper-0.2.1.tar.gz: zookeeper-0.2.1/setup.py <==
from setuptools import setup, find_packages


def readme():
    with open("README.md", "r") as f:
        return f.read()


setup(
    name="zookeeper",
    version="0.2.1",
    author="Plumerai",
    author_email="lukas@plumerai.co.uk",
    description="A small library for managing deep learning models, hyper parameters and datasets",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/plumerai/zookeeper",
    packages=find_packages(),
    license="Apache 2.0",
    install_requires=[
        "click>=7.0",
        "click-completion>=0.5.1",
        "matplotlib>=3.0.3",
        "tensorflow-datasets>=1.0.2",
    ],
    extras_require={
        "tensorflow": ["tensorflow>=1.13.1"],
        "tensorflow_gpu": ["tensorflow-gpu>=1.13.1"],
        "test": ["pytest>=4.3.1", "pytest-cov>=2.6.1"],
    },
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Mathematics",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Software Development",
    ],
)

==> zookeeper-0.3.0.tar.gz: zookeeper-0.3.0/setup.py <==
from setuptools import setup, find_packages


def readme():
    with open("README.md", "r") as f:
        return f.read()


setup(
    name="zookeeper",
    version="0.3.0",
    author="Plumerai",
    author_email="lukas@plumerai.co.uk",
    description="A small library for managing deep learning models, hyper parameters and datasets",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/larq/zookeeper",
    packages=find_packages(),
    license="Apache 2.0",
    install_requires=[
        "click>=7.0",
        "click-completion>=0.5.1",
        "matplotlib>=3.0.3",
        "tensorflow-datasets>=1.0.2",
    ],
    extras_require={
        "tensorflow": ["tensorflow>=1.13.1"],
        "tensorflow_gpu": ["tensorflow-gpu>=1.13.1"],
        "test": ["pytest>=4.3.1", "pytest-cov>=2.6.1"],
    },
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Mathematics",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Software Development",
    ],
)
